<?php
/**
 * Presets for Language Manager.
 *
 * @package nLingual
 * @subpackage Utilities
 *
 * @since 2.7.0 Added accept_code presets.
 * @since 2.0.0
 *
 * @return array The preset list.
 */

return array(
	'ar' => array(
		'system_name' => __( 'Arabic', 'nlingual' ),
		'native_name' => 'العربية',
		'short_name'  => 'العربية',
		'locale_name' => 'ar',
		'accept_code' => 'ar',
		'direction'   => 'rtl',
	),
	'zh' => array(
		'system_name' => __( 'Chinese', 'nlingual' ),
		'native_name' => '中文',
		'short_name'  => '中文',
		'locale_name' => 'zh_CN',
		'accept_code' => 'zh, zh_CN',
		'direction'   => 'ltr',
	),
	'cs' => array(
		'system_name' => __( 'Czech', 'nlingual' ),
		'native_name' => 'čeština',
		'short_name'  => 'Če',
		'locale_name' => 'cs_CZ',
		'accept_code' => 'cs, cs_CZ',
		'direction'   => 'ltr',
	),
	'nl' => array(
		'system_name' => __( 'Dutch', 'nlingual' ),
		'native_name' => 'Nederlands',
		'short_name'  => 'Nl',
		'locale_name' => 'nl_NL',
		'accept_code' => 'nl, nl_NL',
		'direction'   => 'ltr',
	),
	'en' => array(
		'system_name' => __( 'English', 'nlingual' ),
		'native_name' => 'English',
		'short_name'  => 'En',
		'locale_name' => 'en_US',
		'accept_code' => 'en, en_US',
		'direction'   => 'ltr',
	),
	'fi' => array(
		'system_name' => __( 'Finnish', 'nlingual' ),
		'native_name' => 'Sumoi',
		'short_name'  => 'Fi',
		'locale_name' => 'fi',
		'accept_code' => 'fi',
		'direction'   => 'ltr',
	),
	'fr' => array(
		'system_name' => __( 'French', 'nlingual' ),
		'native_name' => 'Français',
		'short_name'  => 'Fr',
		'locale_name' => 'fr_FR',
		'accept_code' => 'fr, fr_FR',
		'direction'   => 'ltr',
	),
	'de' => array(
		'system_name' => __( 'German', 'nlingual' ),
		'native_name' => 'Deutsch',
		'short_name'  => 'De',
		'locale_name' => 'de_DE',
		'accept_code' => 'de, de_DE',
		'direction'   => 'ltr',
	),
	'el' => array(
		'system_name' => __( 'Greek', 'nlingual' ),
		'native_name' => 'ελληνικά',
		'short_name'  => 'ελ',
		'locale_name' => 'el_GR',
		'accept_code' => 'el, el_GR',
		'direction'   => 'ltr',
	),
	'hi' => array(
		'system_name' => __( 'Hindi', 'nlingual' ),
		'native_name' => 'हिन्दी',
		'short_name'  => 'हिंदी',
		'locale_name' => 'hi_IN',
		'accept_code' => 'hi, hi_IN',
		'direction'   => 'ltr',
	),
	'hu' => array(
		'system_name' => __( 'Hungarian', 'nlingual' ),
		'native_name' => 'Magyar',
		'short_name'  => 'Ma',
		'locale_name' => 'hu_HU',
		'accept_code' => 'hu, hu_HU',
		'direction'   => 'ltr',
	),
	'it' => array(
		'system_name' => __( 'Italian', 'nlingual' ),
		'native_name' => 'Italiano',
		'short_name'  => 'It',
		'locale_name' => 'it_IT',
		'accept_code' => 'it, it_IT',
		'direction'   => 'ltr',
	),
	'ja' => array(
		'system_name' => __( 'Japanese', 'nlingual' ),
		'native_name' => '日本語',
		'short_name'  => '日本語',
		'locale_name' => 'ja',
		'accept_code' => 'ja',
		'direction'   => 'ltr',
	),
	'ko' => array(
		'system_name' => __( 'Korean', 'nlingual' ),
		'native_name' => '한국말',
		'short_name'  => '국어',
		'locale_name' => 'ko_KR',
		'accept_code' => 'ko, ko_KR',
		'direction'   => 'ltr',
	),
	'fa' => array(
		'system_name' => __( 'Persian', 'nlingual' ),
		'native_name' => 'فارسی',
		'short_name'  => 'فارسی',
		'locale_name' => 'fa',
		'accept_code' => 'fa',
		'direction'   => 'rtl',
	),
	'pl' => array(
		'system_name' => __( 'Polish', 'nlingual' ),
		'native_name' => 'Polski',
		'short_name'  => 'Pl',
		'locale_name' => 'pl_PL',
		'accept_code' => 'pl, pl_PL',
		'direction'   => 'ltr',
	),
	'pt' => array(
		'system_name' => __( 'Portugese', 'nlingual' ),
		'native_name' => 'Português',
		'short_name'  => 'Pt',
		'locale_name' => 'pt_BR',
		'accept_code' => 'pt, pt_BR',
		'direction'   => 'ltr',
	),
	'ro' => array(
		'system_name' => __( 'Romanian', 'nlingual' ),
		'native_name' => 'Română',
		'short_name'  => 'Ro',
		'locale_name' => 'ro_RO',
		'accept_code' => 'ro, ro_RO',
		'direction'   => 'ltr',
	),
	'ru' => array(
		'system_name' => __( 'Russian', 'nlingual' ),
		'native_name' => 'Русский язык',
		'short_name'  => 'Ру',
		'locale_name' => 'ru_RU',
		'accept_code' => 'ru, ru_RU',
		'direction'   => 'ltr',
	),
	'es' => array(
		'system_name' => __( 'Spanish', 'nlingual' ),
		'native_name' => 'Español',
		'short_name'  => 'Es',
		'locale_name' => 'es_ES',
		'accept_code' => 'es, es_ES',
		'direction'   => 'ltr',
	),
	'sv' => array(
		'system_name' => __( 'Swedish', 'nlingual' ),
		'native_name' => 'Svenska',
		'short_name'  => 'Sv',
		'locale_name' => 'sv_SE',
		'accept_code' => 'sv, sv_SE',
		'direction'   => 'ltr',
	),
	'vi' => array(
		'system_name' => __( 'Vietnamese', 'nlingual' ),
		'native_name' => 'Tiếng Việt',
		'short_name'  => 'Vi',
		'locale_name' => 'vi',
		'accept_code' => 'vi',
		'direction'   => 'ltr',
	),
);
